==> v8.3.zip: ru_twords_ru_tw/bible/other/know.md <==
# знать, знание, познание

## Определение:

В современном мире понятие “знание” обычно означает информацию, известную людям: “знать что-то” означает “иметь информацию о чём-то”, а “знать кого-то” означает “быть знакомым с кем-то”.

* В Библии (как это было принято на Древнем Ближнем Востоке) “знание” означает скорее навыки и умения, то есть применение информации на практике, и соответственно, “знать что-то” означает “уметь что-то”, а “знать кого-то” означает “иметь близкое общение с кем-то”.
* “Знать Бога” означает не просто “знать, что Бог есть”; это значить “жить в общении с Богом” - молиться, исполнять Его заповеди и т.д.
* “Знать Закон” означает “знать, что написано в Законе Моисея и жить в соответствии с этим Законом”.
* Иногда слово “знание” используется как синоним слову “мудрость”, то есть обозначает ещё и “жить так, чтобы угождать Богу”.* Иногда словосочетание “знать Бога” используется как синоним “бояться Бога” (в смысле “иметь такие близкие отношения с Богом, что бояться Его оскорбить или обидеть”.
* Иногда в Библии слово “познать” используется (в контексте отношений мужчины и женщины) в качестве эвфемизма для обозначения интимных (половых) отношений.

## Варианты перевода

* В зависимости от контекста, слово “знать” может переводиться как “понимать”, “быть осведомлённым”, “быть знакомым с”, “иметь взаимоотношения c”.
* Употребление этого слова в различных языках может иметь свои особенности.
* В некоторых языках существуют два (или более) различных глагола для передачи смысла словосочетания “знать кого-либо” – один глагол для обозначения факта простого знакомства, и другой глагол для обозначения взаимоотношений.
* Словосочетание “познавать истину богопочитания” можно перевести как “жить так, чтобы это соответствовало требованиям Бога” или “поступать так, чтобы эти поступки прославляли Бога”.
* Словосочетание “знать Бога” можно перевести как “поклоняться Богу и жить в соответствии с Его заповедями”.
* Словосочетание “сделать известным” можно перевести как “открыть”, “рассказать” или “объяснить”.
* Словосочетание “знать кого-либо” можно перевести как “понимать кого-либо”, “быть знакомым с кем-либо”.

(См. также: [закон](../kt/lawofmoses.md), [открывать](../kt/reveal.md), [понимать](../other/understand.md), [мудрый](../kt/wise.md))

## Ссылки на библейский текст:

* [1 Кор. 2:12-13](rc://*/tn/help/1co/02/12)
* [1 Цар. 17:46](rc://*/tn/help/1sa/17/46)
* [2 Кор. 2:15](rc://*/tn/help/2co/02/15)
* [2 Пет. 1:3-4](rc://*/tn/help/2pe/01/03)
* [Втор. 4:39-40](rc://*/tn/help/deu/04/39)
* [Быт. 19:5](rc://*/tn/help/gen/19/05)
* [Лк. 1:77](rc://*/tn/help/luk/01/77)

## Данные о слове:

* Номера Стронга: H1843, H1844, H1847, H1875, H3045, H3046, H4093, H4486, H5046, H5234, H5475, H5869, G50, G56, G1097, G1107, G1108, G1231, G1492, G1921, G1922, G1987, G2467, G2589, G3877, G4267, G4894

==> v9.2.zip: ru_twords_ru_tw/bible/other/know.md <==
# знать, знание, познание, понимать

## Определение:

В современном мире понятие “знание” обычно означает информацию, известную людям: “знать что-то” означает “иметь информацию о чём-то”, а “знать кого-то” означает “быть знакомым с кем-то”.

* В Библии (как это было принято на Древнем Ближнем Востоке) “знание” означает скорее навыки и умения, то есть применение информации на практике. Соответственно, “знать что-то” означает “уметь что-то”, а “знать кого-то” означает “иметь близкое общение с кем-то”.
* “Знать Бога” означает не просто “знать, что Бог есть”; это значит “жить в общении с Богом” — молиться, исполнять Его заповеди и т.д.
* “Знать Закон” означает “знать, что написано в Законе Моисея и жить в соответствии с этим Законом”.
* Слово “знание” может использоваться как синоним слова “мудрость”, то есть обозначает ещё и “жить так, чтобы угождать Богу”.
* Словосочетание “знать Бога” может использоваться как синоним “бояться Бога” (в смысле “иметь такие близкие отношения с Богом, что бояться Его оскорбить или обидеть”.
* Иногда в Библии слово “познать” используется (в контексте отношений мужчины и женщины) в качестве эвфемизма для обозначения интимных (половых) отношений.

## Варианты перевода

* В зависимости от контекста, слово “знать” может переводиться как “понимать”, “быть осведомлённым”, “быть знакомым с”, “иметь взаимоотношения c”.
* Употребление этого слова в различных языках может иметь свои особенности.
* В некоторых языках существуют два (или более) различных глагола для передачи смысла словосочетания “знать кого-либо” – один глагол для обозначения факта простого знакомства, и другой глагол для обозначения взаимоотношений.
* Словосочетание “познавать истину богопочитания” можно перевести как “жить так, чтобы это соответствовало требованиям Бога” или “поступать так, чтобы эти поступки прославляли Бога”.
* Словосочетание “знать Бога” можно перевести как “поклоняться Богу и жить в соответствии с Его заповедями”.
* Словосочетание “сделать известным” можно перевести как “открыть”, “рассказать” или “объяснить”.
* Словосочетание “знать кого-либо” можно перевести как “понимать кого-либо”, “быть знакомым с кем-либо”.

(См. также: [закон](../kt/lawofmoses.md), [открывать](../kt/reveal.md), [понимать](../other/understand.md), [мудрый](../kt/wise.md))

## Ссылки на библейский текст:

* [1 Кор. 2:12-13](rc://ru/tn/help/1co/02/12)
* [1 Цар. 17:46](rc://ru/tn/help/1sa/17/46)
* [2 Кор. 2:15](rc://ru/tn/help/2co/02/15)
* [2 Пет. 1:3-4](rc://ru/tn/help/2pe/01/03)
* [Втор. 4:39-40](rc://ru/tn/help/deu/04/39)
* [Быт. 19:5](rc://ru/tn/help/gen/19/05)
* [Лк. 1:77](rc://ru/tn/help/luk/01/77)

## Данные о слове:

* Номера Стронга: H1843, H1844, H1847, H1875, H3045, H3046, H4093, H4486, H5046, H5234, H5475, H5869, G50, G56, G1097, G1107, G1108, G1231, G1492, G1921, G1922, G1987, G2467, G2589, G3877, G4267, G4894
